"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Select = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _utils = require("../../utils");
var _Button = require("../Button");
var _select = require("./select.style");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const Select = _ref => {
  let {
    multiple,
    value,
    onChange,
    options,
    color = 'blue',
    placeholder,
    disabledOptions,
    borderColor
  } = _ref;
  const [isOpen, setIsOpen] = (0, _react.useState)(false);
  const [activeColor, setActiveColor] = (0, _react.useState)((0, _utils.colorMatch)(color));
  (0, _react.useEffect)(() => {
    setActiveColor((0, _utils.colorMatch)(color));
  }, [color]);
  function clearOptions() {
    multiple ? onChange([]) : onChange(undefined);
  }
  function selectOption(option) {
    if (multiple) {
      if (value.includes(option)) {
        onChange(value.filter(o => o !== option));
      } else {
        onChange([...value, option]);
      }
    } else {
      if (option !== value) {
        onChange(option);
      }
    }
  }
  function isOptionSelected(option) {
    return multiple ? value.includes(option) : option === value;
  }
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: _select.styles.wrapper
  }, /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    onBlur: () => setIsOpen(false),
    style: [_select.styles.container, borderColor ? {
      borderColor
    } : {}],
    activeOpacity: 0.7,
    onPress: () => setIsOpen(prev => !prev)
  }, (!value || multiple && value.length === 0) && /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: _select.styles.placeholder
  }, placeholder), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: _select.styles.buttons
  }, multiple ? value.map(v => /*#__PURE__*/_react.default.createElement(_Button.Button, {
    key: v.value,
    title: v.label,
    onPress: () => {
      selectOption(v);
    },
    borderColor: activeColor
  })) : /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: _select.styles.remove
  }, value === null || value === void 0 ? void 0 : value.label)), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: _select.styles.settings
  }, multiple && value.length > 0 && /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    style: _select.styles.remove,
    onPress: clearOptions
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: [_select.styles.text, borderColor ? {
      color: borderColor
    } : {}]
  }, "\xD7")), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [_select.styles.divider, borderColor ? {
      backgroundColor: borderColor
    } : {}]
  }), /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    onPress: () => setIsOpen(prev => !prev)
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: [_select.styles.text, _select.styles.caret, isOpen ? _select.styles.caretOpen : {}, borderColor ? {
      color: borderColor
    } : {}]
  }, "^")))), isOpen && /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: _select.styles.items
  }, options.map(option => /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    onPress: e => {
      if (disabledOptions !== null && disabledOptions !== void 0 && disabledOptions.includes(option)) {
        return;
      }
      e.stopPropagation();
      selectOption(option);
      setIsOpen(false);
    },
    key: option.value,
    style: [_select.styles.item, isOptionSelected(option) ? {
      backgroundColor: `${activeColor}24`,
      borderRadius: 3
    } : {}, disabledOptions !== null && disabledOptions !== void 0 && disabledOptions.includes(option) ? _select.styles.disabled : {}]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, null, option.label)))));
};
exports.Select = Select;
//# sourceMappingURL=Select.js.map