import React, { useEffect, useState } from 'react';
import { View, Text, TouchableOpacity } from 'react-native';
import { colorMatch } from '../../utils';
import { Button } from '../Button';
import { styles } from './select.style';
export const Select = _ref => {
  let {
    multiple,
    value,
    onChange,
    options,
    color = 'blue',
    placeholder,
    disabledOptions,
    borderColor
  } = _ref;
  const [isOpen, setIsOpen] = useState(false);
  const [activeColor, setActiveColor] = useState(colorMatch(color));
  useEffect(() => {
    setActiveColor(colorMatch(color));
  }, [color]);
  function clearOptions() {
    multiple ? onChange([]) : onChange(undefined);
  }
  function selectOption(option) {
    if (multiple) {
      if (value.includes(option)) {
        onChange(value.filter(o => o !== option));
      } else {
        onChange([...value, option]);
      }
    } else {
      if (option !== value) {
        onChange(option);
      }
    }
  }
  function isOptionSelected(option) {
    return multiple ? value.includes(option) : option === value;
  }
  return /*#__PURE__*/React.createElement(View, {
    style: styles.wrapper
  }, /*#__PURE__*/React.createElement(TouchableOpacity, {
    onBlur: () => setIsOpen(false),
    style: [styles.container, borderColor ? {
      borderColor
    } : {}],
    activeOpacity: 0.7,
    onPress: () => setIsOpen(prev => !prev)
  }, (!value || multiple && value.length === 0) && /*#__PURE__*/React.createElement(Text, {
    style: styles.placeholder
  }, placeholder), /*#__PURE__*/React.createElement(View, {
    style: styles.buttons
  }, multiple ? value.map(v => /*#__PURE__*/React.createElement(Button, {
    key: v.value,
    title: v.label,
    onPress: () => {
      selectOption(v);
    },
    borderColor: activeColor
  })) : /*#__PURE__*/React.createElement(Text, {
    style: styles.remove
  }, value === null || value === void 0 ? void 0 : value.label)), /*#__PURE__*/React.createElement(View, {
    style: styles.settings
  }, multiple && value.length > 0 && /*#__PURE__*/React.createElement(TouchableOpacity, {
    style: styles.remove,
    onPress: clearOptions
  }, /*#__PURE__*/React.createElement(Text, {
    style: [styles.text, borderColor ? {
      color: borderColor
    } : {}]
  }, "\xD7")), /*#__PURE__*/React.createElement(View, {
    style: [styles.divider, borderColor ? {
      backgroundColor: borderColor
    } : {}]
  }), /*#__PURE__*/React.createElement(TouchableOpacity, {
    onPress: () => setIsOpen(prev => !prev)
  }, /*#__PURE__*/React.createElement(Text, {
    style: [styles.text, styles.caret, isOpen ? styles.caretOpen : {}, borderColor ? {
      color: borderColor
    } : {}]
  }, "^")))), isOpen && /*#__PURE__*/React.createElement(View, {
    style: styles.items
  }, options.map(option => /*#__PURE__*/React.createElement(TouchableOpacity, {
    onPress: e => {
      if (disabledOptions !== null && disabledOptions !== void 0 && disabledOptions.includes(option)) {
        return;
      }
      e.stopPropagation();
      selectOption(option);
      setIsOpen(false);
    },
    key: option.value,
    style: [styles.item, isOptionSelected(option) ? {
      backgroundColor: `${activeColor}24`,
      borderRadius: 3
    } : {}, disabledOptions !== null && disabledOptions !== void 0 && disabledOptions.includes(option) ? styles.disabled : {}]
  }, /*#__PURE__*/React.createElement(Text, null, option.label)))));
};
//# sourceMappingURL=Select.js.map